@@ -6,17 +6,17 @@ testthat::test_that("examples rstac", {
 
     # test collections - /collections/
     testthat::expect_s3_class(
-      object = rstac::stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
-        rstac::collections() %>%
-        rstac::get_request(),
-      class = c("STACCollectionList", "RSTACDocument"))
+      object = stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
+        collections() %>%
+        get_request(),
+      class = c("doc_collections", "rstac_doc"))
 
     # test collections items - /collections/{collection_id}
     testthat::expect_s3_class(
       object = stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
         collections(collection_id = "CB4-16D-2") %>%
         get_request(),
-      class = c("STACCollection", "STACCatalog", "RSTACDocument"))
+      class = c("doc_collection", "doc_catalog", "rstac_doc"))
 
     # test items collection - /collections/{collection_id}/items
     testthat::expect_s3_class(
@@ -24,7 +24,7 @@ testthat::test_that("examples rstac", {
         collections("CB4-16D-2") %>%
         items(bbox = c(-47.02148, -12.98314, -42.53906, -17.35063)) %>%
         get_request(),
-      class = c("STACItemCollection", "RSTACDocument"))
+      class = c("doc_items", "rstac_doc"))
 
     # test items collection - /search/
     testthat::expect_s3_class(
@@ -32,7 +32,7 @@ testthat::test_that("examples rstac", {
         stac_search(collections = "CB4-16D-2",
                     bbox = c(-47.02148, -12.98314, -42.53906, -17.35063)) %>%
         get_request(),
-      class = c("STACItemCollection", "RSTACDocument"))
+      class = c("doc_items", "rstac_doc"))
 
     # test items collection - /search/
     testthat::expect_s3_class(
@@ -40,7 +40,7 @@ testthat::test_that("examples rstac", {
         stac_search(collections = "CB4-16D-2",
                     bbox = c(-47.02148, -12.98314, -42.53906, -17.35063)) %>%
         post_request(),
-      class = c("STACItemCollection", "RSTACDocument"))
+      class = c("doc_items", "rstac_doc"))
 
     # test stac item - /collections/{collection_id}/items/{feature_id}
     testthat::expect_s3_class(
@@ -48,13 +48,13 @@ testthat::test_that("examples rstac", {
         collections("CB4-16D-2") %>%
         items("CB4-16D_V2_000002_20230509") %>%
         get_request(),
-      class = c("STACItem", "RSTACDocument"))
+      class = c("doc_item", "rstac_doc"))
 
     # test stac catalog - /
     testthat::expect_s3_class(
       object = stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
         get_request(),
-      class = c("STACCatalog", "RSTACDocument"))
+      class = c("doc_catalog", "rstac_doc"))
 
     #### tests in extensions ####
 
@@ -64,7 +64,7 @@ testthat::test_that("examples rstac", {
               stac_search(collections = "CB4-16D-2") %>%
               ext_query("bdc:tile" == "021027") %>%
               post_request(),
-      class = c("STACItem", "RSTACDocument"))
+      class = c("doc_item", "rstac_doc"))
 
     #### tests in items ####
 
@@ -75,7 +75,7 @@ testthat::test_that("examples rstac", {
                     limit = 500) %>%
         get_request() %>%
         items_fetch(),
-      class = c("STACItemCollection", "RSTACDocument"))
+      class = c("doc_items", "rstac_doc"))
 
     # test item_length
     testthat::expect_equal(
@@ -86,62 +86,6 @@ testthat::test_that("examples rstac", {
         items_length(),
       expected = 10)
 
-    # test items_group
-    testthat::expect_error(
-      object =
-        suppressWarnings(
-          stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
-            stac_search(collections = "LCC_C4_64_1M_STK_GO_PA-SPC-AC-NA-1",
-                        limit = 500,
-                        datetime = "2018-09-01/2019-08-31") %>%
-            get_request() %>%
-            items_fetch() %>%
-            items_group()
-        )
-    )
-
-    # test items_group
-    testthat::expect_error(
-      object =
-        suppressWarnings(
-          stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
-            stac_search(collections = "LCC_C4_64_1M_STK_GO_PA-SPC-AC-NA-1",
-                        limit = 500,
-                        datetime = "2018-09-01/2019-08-31") %>%
-            get_request() %>%
-            items_fetch() %>%
-            items_group()
-        )
-    )
-
-    # test items_group
-    testthat::expect_error(
-      object =
-        suppressWarnings(
-          stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
-            stac_search(collections = "LCC_C4_64_1M_STK_GO_PA-SPC-AC-NA-1",
-                        limit = 500,
-                        datetime = "2018-09-01/2019-08-31") %>%
-            get_request() %>%
-            items_fetch() %>%
-            items_group(field = "test", index = "test")
-        )
-    )
-
-    # test items_group
-    testthat::expect_error(
-      object =
-        suppressWarnings(
-          stac("https://brazildatacube.dpi.inpe.br/stac/") %>%
-            stac_search(collections = "LCC_C4_64_1M_STK_GO_PA-SPC-AC-NA-1",
-                        limit = 500,
-                        datetime = "2018-09-01/2019-08-31") %>%
-            get_request() %>%
-            items_fetch() %>%
-            items_group(index = list(1, 2, 3))
-        )
-    )
-
     # test items_reap
     testthat::expect_equal(
       object = typeof(
